"""PartFEAnalysis"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private.system_model.analyses_and_results.analysis_cases import _7713
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import
from mastapy._private._internal import utility

_PART_FE_ANALYSIS = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.AnalysisCases", "PartFEAnalysis"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.system_model.analyses_and_results.system_deflections import (
        _2768,
        _2769,
        _2770,
        _2773,
        _2774,
        _2775,
        _2781,
        _2783,
        _2785,
        _2786,
        _2787,
        _2788,
        _2790,
        _2791,
        _2792,
        _2793,
        _2795,
        _2796,
        _2798,
        _2801,
        _2802,
        _2804,
        _2805,
        _2808,
        _2809,
        _2811,
        _2813,
        _2814,
        _2816,
        _2817,
        _2818,
        _2821,
        _2825,
        _2826,
        _2827,
        _2828,
        _2829,
        _2830,
        _2833,
        _2834,
        _2835,
        _2838,
        _2839,
        _2840,
        _2841,
        _2843,
        _2844,
        _2845,
        _2847,
        _2848,
        _2852,
        _2853,
        _2855,
        _2856,
        _2858,
        _2859,
        _2862,
        _2863,
        _2865,
        _2866,
        _2867,
        _2869,
        _2870,
        _2872,
        _2873,
        _2875,
        _2876,
        _2877,
        _2878,
        _2879,
        _2882,
        _2884,
        _2885,
        _2886,
        _2889,
        _2891,
        _2893,
        _2894,
        _2896,
        _2897,
        _2899,
        _2900,
        _2902,
        _2903,
        _2904,
        _2905,
        _2906,
        _2907,
        _2908,
        _2909,
        _2914,
        _2915,
        _2916,
        _2919,
        _2920,
        _2922,
        _2923,
        _2925,
        _2926,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
        _6415,
        _6416,
        _6417,
        _6419,
        _6421,
        _6422,
        _6423,
        _6425,
        _6426,
        _6428,
        _6429,
        _6430,
        _6431,
        _6433,
        _6434,
        _6435,
        _6437,
        _6438,
        _6440,
        _6442,
        _6443,
        _6444,
        _6446,
        _6447,
        _6449,
        _6451,
        _6453,
        _6454,
        _6456,
        _6457,
        _6458,
        _6460,
        _6462,
        _6464,
        _6465,
        _6466,
        _6469,
        _6470,
        _6472,
        _6473,
        _6474,
        _6475,
        _6477,
        _6478,
        _6479,
        _6481,
        _6483,
        _6485,
        _6486,
        _6488,
        _6489,
        _6491,
        _6492,
        _6493,
        _6494,
        _6495,
        _6496,
        _6497,
        _6498,
        _6500,
        _6501,
        _6503,
        _6504,
        _6505,
        _6506,
        _6507,
        _6508,
        _6510,
        _6512,
        _6513,
        _6514,
        _6515,
        _6517,
        _6518,
        _6520,
        _6522,
        _6523,
        _6524,
        _6526,
        _6527,
        _6529,
        _6530,
        _6531,
        _6532,
        _6533,
        _6534,
        _6535,
        _6537,
        _6538,
        _6539,
        _6540,
        _6541,
        _6542,
        _6544,
        _6545,
        _6547,
    )
    from mastapy._private.system_model.analyses_and_results.analysis_cases import _7710
    from mastapy._private.system_model.analyses_and_results import _2740, _2736, _2734

    Self = TypeVar("Self", bound="PartFEAnalysis")
    CastSelf = TypeVar("CastSelf", bound="PartFEAnalysis._Cast_PartFEAnalysis")


__docformat__ = "restructuredtext en"
__all__ = ("PartFEAnalysis",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_PartFEAnalysis:
    """Special nested class for casting PartFEAnalysis to subclasses."""

    __parent__: "PartFEAnalysis"

    @property
    def part_static_load_analysis_case(
        self: "CastSelf",
    ) -> "_7713.PartStaticLoadAnalysisCase":
        return self.__parent__._cast(_7713.PartStaticLoadAnalysisCase)

    @property
    def part_analysis_case(self: "CastSelf") -> "_7710.PartAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7710,
        )

        return self.__parent__._cast(_7710.PartAnalysisCase)

    @property
    def part_analysis(self: "CastSelf") -> "_2740.PartAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2740

        return self.__parent__._cast(_2740.PartAnalysis)

    @property
    def design_entity_single_context_analysis(
        self: "CastSelf",
    ) -> "_2736.DesignEntitySingleContextAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2736

        return self.__parent__._cast(_2736.DesignEntitySingleContextAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2734.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2734

        return self.__parent__._cast(_2734.DesignEntityAnalysis)

    @property
    def abstract_assembly_system_deflection(
        self: "CastSelf",
    ) -> "_2768.AbstractAssemblySystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2768,
        )

        return self.__parent__._cast(_2768.AbstractAssemblySystemDeflection)

    @property
    def abstract_shaft_or_housing_system_deflection(
        self: "CastSelf",
    ) -> "_2769.AbstractShaftOrHousingSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2769,
        )

        return self.__parent__._cast(_2769.AbstractShaftOrHousingSystemDeflection)

    @property
    def abstract_shaft_system_deflection(
        self: "CastSelf",
    ) -> "_2770.AbstractShaftSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2770,
        )

        return self.__parent__._cast(_2770.AbstractShaftSystemDeflection)

    @property
    def agma_gleason_conical_gear_set_system_deflection(
        self: "CastSelf",
    ) -> "_2773.AGMAGleasonConicalGearSetSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2773,
        )

        return self.__parent__._cast(_2773.AGMAGleasonConicalGearSetSystemDeflection)

    @property
    def agma_gleason_conical_gear_system_deflection(
        self: "CastSelf",
    ) -> "_2774.AGMAGleasonConicalGearSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2774,
        )

        return self.__parent__._cast(_2774.AGMAGleasonConicalGearSystemDeflection)

    @property
    def assembly_system_deflection(
        self: "CastSelf",
    ) -> "_2775.AssemblySystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2775,
        )

        return self.__parent__._cast(_2775.AssemblySystemDeflection)

    @property
    def bearing_system_deflection(self: "CastSelf") -> "_2781.BearingSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2781,
        )

        return self.__parent__._cast(_2781.BearingSystemDeflection)

    @property
    def belt_drive_system_deflection(
        self: "CastSelf",
    ) -> "_2783.BeltDriveSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2783,
        )

        return self.__parent__._cast(_2783.BeltDriveSystemDeflection)

    @property
    def bevel_differential_gear_set_system_deflection(
        self: "CastSelf",
    ) -> "_2785.BevelDifferentialGearSetSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2785,
        )

        return self.__parent__._cast(_2785.BevelDifferentialGearSetSystemDeflection)

    @property
    def bevel_differential_gear_system_deflection(
        self: "CastSelf",
    ) -> "_2786.BevelDifferentialGearSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2786,
        )

        return self.__parent__._cast(_2786.BevelDifferentialGearSystemDeflection)

    @property
    def bevel_differential_planet_gear_system_deflection(
        self: "CastSelf",
    ) -> "_2787.BevelDifferentialPlanetGearSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2787,
        )

        return self.__parent__._cast(_2787.BevelDifferentialPlanetGearSystemDeflection)

    @property
    def bevel_differential_sun_gear_system_deflection(
        self: "CastSelf",
    ) -> "_2788.BevelDifferentialSunGearSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2788,
        )

        return self.__parent__._cast(_2788.BevelDifferentialSunGearSystemDeflection)

    @property
    def bevel_gear_set_system_deflection(
        self: "CastSelf",
    ) -> "_2790.BevelGearSetSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2790,
        )

        return self.__parent__._cast(_2790.BevelGearSetSystemDeflection)

    @property
    def bevel_gear_system_deflection(
        self: "CastSelf",
    ) -> "_2791.BevelGearSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2791,
        )

        return self.__parent__._cast(_2791.BevelGearSystemDeflection)

    @property
    def bolted_joint_system_deflection(
        self: "CastSelf",
    ) -> "_2792.BoltedJointSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2792,
        )

        return self.__parent__._cast(_2792.BoltedJointSystemDeflection)

    @property
    def bolt_system_deflection(self: "CastSelf") -> "_2793.BoltSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2793,
        )

        return self.__parent__._cast(_2793.BoltSystemDeflection)

    @property
    def clutch_half_system_deflection(
        self: "CastSelf",
    ) -> "_2795.ClutchHalfSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2795,
        )

        return self.__parent__._cast(_2795.ClutchHalfSystemDeflection)

    @property
    def clutch_system_deflection(self: "CastSelf") -> "_2796.ClutchSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2796,
        )

        return self.__parent__._cast(_2796.ClutchSystemDeflection)

    @property
    def component_system_deflection(
        self: "CastSelf",
    ) -> "_2798.ComponentSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2798,
        )

        return self.__parent__._cast(_2798.ComponentSystemDeflection)

    @property
    def concept_coupling_half_system_deflection(
        self: "CastSelf",
    ) -> "_2801.ConceptCouplingHalfSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2801,
        )

        return self.__parent__._cast(_2801.ConceptCouplingHalfSystemDeflection)

    @property
    def concept_coupling_system_deflection(
        self: "CastSelf",
    ) -> "_2802.ConceptCouplingSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2802,
        )

        return self.__parent__._cast(_2802.ConceptCouplingSystemDeflection)

    @property
    def concept_gear_set_system_deflection(
        self: "CastSelf",
    ) -> "_2804.ConceptGearSetSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2804,
        )

        return self.__parent__._cast(_2804.ConceptGearSetSystemDeflection)

    @property
    def concept_gear_system_deflection(
        self: "CastSelf",
    ) -> "_2805.ConceptGearSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2805,
        )

        return self.__parent__._cast(_2805.ConceptGearSystemDeflection)

    @property
    def conical_gear_set_system_deflection(
        self: "CastSelf",
    ) -> "_2808.ConicalGearSetSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2808,
        )

        return self.__parent__._cast(_2808.ConicalGearSetSystemDeflection)

    @property
    def conical_gear_system_deflection(
        self: "CastSelf",
    ) -> "_2809.ConicalGearSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2809,
        )

        return self.__parent__._cast(_2809.ConicalGearSystemDeflection)

    @property
    def connector_system_deflection(
        self: "CastSelf",
    ) -> "_2811.ConnectorSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2811,
        )

        return self.__parent__._cast(_2811.ConnectorSystemDeflection)

    @property
    def coupling_half_system_deflection(
        self: "CastSelf",
    ) -> "_2813.CouplingHalfSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2813,
        )

        return self.__parent__._cast(_2813.CouplingHalfSystemDeflection)

    @property
    def coupling_system_deflection(
        self: "CastSelf",
    ) -> "_2814.CouplingSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2814,
        )

        return self.__parent__._cast(_2814.CouplingSystemDeflection)

    @property
    def cvt_pulley_system_deflection(
        self: "CastSelf",
    ) -> "_2816.CVTPulleySystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2816,
        )

        return self.__parent__._cast(_2816.CVTPulleySystemDeflection)

    @property
    def cvt_system_deflection(self: "CastSelf") -> "_2817.CVTSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2817,
        )

        return self.__parent__._cast(_2817.CVTSystemDeflection)

    @property
    def cycloidal_assembly_system_deflection(
        self: "CastSelf",
    ) -> "_2818.CycloidalAssemblySystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2818,
        )

        return self.__parent__._cast(_2818.CycloidalAssemblySystemDeflection)

    @property
    def cycloidal_disc_system_deflection(
        self: "CastSelf",
    ) -> "_2821.CycloidalDiscSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2821,
        )

        return self.__parent__._cast(_2821.CycloidalDiscSystemDeflection)

    @property
    def cylindrical_gear_set_system_deflection(
        self: "CastSelf",
    ) -> "_2825.CylindricalGearSetSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2825,
        )

        return self.__parent__._cast(_2825.CylindricalGearSetSystemDeflection)

    @property
    def cylindrical_gear_set_system_deflection_timestep(
        self: "CastSelf",
    ) -> "_2826.CylindricalGearSetSystemDeflectionTimestep":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2826,
        )

        return self.__parent__._cast(_2826.CylindricalGearSetSystemDeflectionTimestep)

    @property
    def cylindrical_gear_set_system_deflection_with_ltca_results(
        self: "CastSelf",
    ) -> "_2827.CylindricalGearSetSystemDeflectionWithLTCAResults":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2827,
        )

        return self.__parent__._cast(
            _2827.CylindricalGearSetSystemDeflectionWithLTCAResults
        )

    @property
    def cylindrical_gear_system_deflection(
        self: "CastSelf",
    ) -> "_2828.CylindricalGearSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2828,
        )

        return self.__parent__._cast(_2828.CylindricalGearSystemDeflection)

    @property
    def cylindrical_gear_system_deflection_timestep(
        self: "CastSelf",
    ) -> "_2829.CylindricalGearSystemDeflectionTimestep":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2829,
        )

        return self.__parent__._cast(_2829.CylindricalGearSystemDeflectionTimestep)

    @property
    def cylindrical_gear_system_deflection_with_ltca_results(
        self: "CastSelf",
    ) -> "_2830.CylindricalGearSystemDeflectionWithLTCAResults":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2830,
        )

        return self.__parent__._cast(
            _2830.CylindricalGearSystemDeflectionWithLTCAResults
        )

    @property
    def cylindrical_planet_gear_system_deflection(
        self: "CastSelf",
    ) -> "_2833.CylindricalPlanetGearSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2833,
        )

        return self.__parent__._cast(_2833.CylindricalPlanetGearSystemDeflection)

    @property
    def datum_system_deflection(self: "CastSelf") -> "_2834.DatumSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2834,
        )

        return self.__parent__._cast(_2834.DatumSystemDeflection)

    @property
    def external_cad_model_system_deflection(
        self: "CastSelf",
    ) -> "_2835.ExternalCADModelSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2835,
        )

        return self.__parent__._cast(_2835.ExternalCADModelSystemDeflection)

    @property
    def face_gear_set_system_deflection(
        self: "CastSelf",
    ) -> "_2838.FaceGearSetSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2838,
        )

        return self.__parent__._cast(_2838.FaceGearSetSystemDeflection)

    @property
    def face_gear_system_deflection(
        self: "CastSelf",
    ) -> "_2839.FaceGearSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2839,
        )

        return self.__parent__._cast(_2839.FaceGearSystemDeflection)

    @property
    def fe_part_system_deflection(self: "CastSelf") -> "_2840.FEPartSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2840,
        )

        return self.__parent__._cast(_2840.FEPartSystemDeflection)

    @property
    def flexible_pin_assembly_system_deflection(
        self: "CastSelf",
    ) -> "_2841.FlexiblePinAssemblySystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2841,
        )

        return self.__parent__._cast(_2841.FlexiblePinAssemblySystemDeflection)

    @property
    def gear_set_system_deflection(self: "CastSelf") -> "_2843.GearSetSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2843,
        )

        return self.__parent__._cast(_2843.GearSetSystemDeflection)

    @property
    def gear_system_deflection(self: "CastSelf") -> "_2844.GearSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2844,
        )

        return self.__parent__._cast(_2844.GearSystemDeflection)

    @property
    def guide_dxf_model_system_deflection(
        self: "CastSelf",
    ) -> "_2845.GuideDxfModelSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2845,
        )

        return self.__parent__._cast(_2845.GuideDxfModelSystemDeflection)

    @property
    def hypoid_gear_set_system_deflection(
        self: "CastSelf",
    ) -> "_2847.HypoidGearSetSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2847,
        )

        return self.__parent__._cast(_2847.HypoidGearSetSystemDeflection)

    @property
    def hypoid_gear_system_deflection(
        self: "CastSelf",
    ) -> "_2848.HypoidGearSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2848,
        )

        return self.__parent__._cast(_2848.HypoidGearSystemDeflection)

    @property
    def klingelnberg_cyclo_palloid_conical_gear_set_system_deflection(
        self: "CastSelf",
    ) -> "_2852.KlingelnbergCycloPalloidConicalGearSetSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2852,
        )

        return self.__parent__._cast(
            _2852.KlingelnbergCycloPalloidConicalGearSetSystemDeflection
        )

    @property
    def klingelnberg_cyclo_palloid_conical_gear_system_deflection(
        self: "CastSelf",
    ) -> "_2853.KlingelnbergCycloPalloidConicalGearSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2853,
        )

        return self.__parent__._cast(
            _2853.KlingelnbergCycloPalloidConicalGearSystemDeflection
        )

    @property
    def klingelnberg_cyclo_palloid_hypoid_gear_set_system_deflection(
        self: "CastSelf",
    ) -> "_2855.KlingelnbergCycloPalloidHypoidGearSetSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2855,
        )

        return self.__parent__._cast(
            _2855.KlingelnbergCycloPalloidHypoidGearSetSystemDeflection
        )

    @property
    def klingelnberg_cyclo_palloid_hypoid_gear_system_deflection(
        self: "CastSelf",
    ) -> "_2856.KlingelnbergCycloPalloidHypoidGearSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2856,
        )

        return self.__parent__._cast(
            _2856.KlingelnbergCycloPalloidHypoidGearSystemDeflection
        )

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_gear_set_system_deflection(
        self: "CastSelf",
    ) -> "_2858.KlingelnbergCycloPalloidSpiralBevelGearSetSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2858,
        )

        return self.__parent__._cast(
            _2858.KlingelnbergCycloPalloidSpiralBevelGearSetSystemDeflection
        )

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_gear_system_deflection(
        self: "CastSelf",
    ) -> "_2859.KlingelnbergCycloPalloidSpiralBevelGearSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2859,
        )

        return self.__parent__._cast(
            _2859.KlingelnbergCycloPalloidSpiralBevelGearSystemDeflection
        )

    @property
    def mass_disc_system_deflection(
        self: "CastSelf",
    ) -> "_2862.MassDiscSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2862,
        )

        return self.__parent__._cast(_2862.MassDiscSystemDeflection)

    @property
    def measurement_component_system_deflection(
        self: "CastSelf",
    ) -> "_2863.MeasurementComponentSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2863,
        )

        return self.__parent__._cast(_2863.MeasurementComponentSystemDeflection)

    @property
    def microphone_array_system_deflection(
        self: "CastSelf",
    ) -> "_2865.MicrophoneArraySystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2865,
        )

        return self.__parent__._cast(_2865.MicrophoneArraySystemDeflection)

    @property
    def microphone_system_deflection(
        self: "CastSelf",
    ) -> "_2866.MicrophoneSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2866,
        )

        return self.__parent__._cast(_2866.MicrophoneSystemDeflection)

    @property
    def mountable_component_system_deflection(
        self: "CastSelf",
    ) -> "_2867.MountableComponentSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2867,
        )

        return self.__parent__._cast(_2867.MountableComponentSystemDeflection)

    @property
    def oil_seal_system_deflection(self: "CastSelf") -> "_2869.OilSealSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2869,
        )

        return self.__parent__._cast(_2869.OilSealSystemDeflection)

    @property
    def part_system_deflection(self: "CastSelf") -> "_2870.PartSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2870,
        )

        return self.__parent__._cast(_2870.PartSystemDeflection)

    @property
    def part_to_part_shear_coupling_half_system_deflection(
        self: "CastSelf",
    ) -> "_2872.PartToPartShearCouplingHalfSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2872,
        )

        return self.__parent__._cast(_2872.PartToPartShearCouplingHalfSystemDeflection)

    @property
    def part_to_part_shear_coupling_system_deflection(
        self: "CastSelf",
    ) -> "_2873.PartToPartShearCouplingSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2873,
        )

        return self.__parent__._cast(_2873.PartToPartShearCouplingSystemDeflection)

    @property
    def planet_carrier_system_deflection(
        self: "CastSelf",
    ) -> "_2875.PlanetCarrierSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2875,
        )

        return self.__parent__._cast(_2875.PlanetCarrierSystemDeflection)

    @property
    def point_load_system_deflection(
        self: "CastSelf",
    ) -> "_2876.PointLoadSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2876,
        )

        return self.__parent__._cast(_2876.PointLoadSystemDeflection)

    @property
    def power_load_system_deflection(
        self: "CastSelf",
    ) -> "_2877.PowerLoadSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2877,
        )

        return self.__parent__._cast(_2877.PowerLoadSystemDeflection)

    @property
    def pulley_system_deflection(self: "CastSelf") -> "_2878.PulleySystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2878,
        )

        return self.__parent__._cast(_2878.PulleySystemDeflection)

    @property
    def ring_pins_system_deflection(
        self: "CastSelf",
    ) -> "_2879.RingPinsSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2879,
        )

        return self.__parent__._cast(_2879.RingPinsSystemDeflection)

    @property
    def rolling_ring_assembly_system_deflection(
        self: "CastSelf",
    ) -> "_2882.RollingRingAssemblySystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2882,
        )

        return self.__parent__._cast(_2882.RollingRingAssemblySystemDeflection)

    @property
    def rolling_ring_system_deflection(
        self: "CastSelf",
    ) -> "_2884.RollingRingSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2884,
        )

        return self.__parent__._cast(_2884.RollingRingSystemDeflection)

    @property
    def root_assembly_system_deflection(
        self: "CastSelf",
    ) -> "_2885.RootAssemblySystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2885,
        )

        return self.__parent__._cast(_2885.RootAssemblySystemDeflection)

    @property
    def shaft_hub_connection_system_deflection(
        self: "CastSelf",
    ) -> "_2886.ShaftHubConnectionSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2886,
        )

        return self.__parent__._cast(_2886.ShaftHubConnectionSystemDeflection)

    @property
    def shaft_system_deflection(self: "CastSelf") -> "_2889.ShaftSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2889,
        )

        return self.__parent__._cast(_2889.ShaftSystemDeflection)

    @property
    def specialised_assembly_system_deflection(
        self: "CastSelf",
    ) -> "_2891.SpecialisedAssemblySystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2891,
        )

        return self.__parent__._cast(_2891.SpecialisedAssemblySystemDeflection)

    @property
    def spiral_bevel_gear_set_system_deflection(
        self: "CastSelf",
    ) -> "_2893.SpiralBevelGearSetSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2893,
        )

        return self.__parent__._cast(_2893.SpiralBevelGearSetSystemDeflection)

    @property
    def spiral_bevel_gear_system_deflection(
        self: "CastSelf",
    ) -> "_2894.SpiralBevelGearSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2894,
        )

        return self.__parent__._cast(_2894.SpiralBevelGearSystemDeflection)

    @property
    def spring_damper_half_system_deflection(
        self: "CastSelf",
    ) -> "_2896.SpringDamperHalfSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2896,
        )

        return self.__parent__._cast(_2896.SpringDamperHalfSystemDeflection)

    @property
    def spring_damper_system_deflection(
        self: "CastSelf",
    ) -> "_2897.SpringDamperSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2897,
        )

        return self.__parent__._cast(_2897.SpringDamperSystemDeflection)

    @property
    def straight_bevel_diff_gear_set_system_deflection(
        self: "CastSelf",
    ) -> "_2899.StraightBevelDiffGearSetSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2899,
        )

        return self.__parent__._cast(_2899.StraightBevelDiffGearSetSystemDeflection)

    @property
    def straight_bevel_diff_gear_system_deflection(
        self: "CastSelf",
    ) -> "_2900.StraightBevelDiffGearSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2900,
        )

        return self.__parent__._cast(_2900.StraightBevelDiffGearSystemDeflection)

    @property
    def straight_bevel_gear_set_system_deflection(
        self: "CastSelf",
    ) -> "_2902.StraightBevelGearSetSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2902,
        )

        return self.__parent__._cast(_2902.StraightBevelGearSetSystemDeflection)

    @property
    def straight_bevel_gear_system_deflection(
        self: "CastSelf",
    ) -> "_2903.StraightBevelGearSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2903,
        )

        return self.__parent__._cast(_2903.StraightBevelGearSystemDeflection)

    @property
    def straight_bevel_planet_gear_system_deflection(
        self: "CastSelf",
    ) -> "_2904.StraightBevelPlanetGearSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2904,
        )

        return self.__parent__._cast(_2904.StraightBevelPlanetGearSystemDeflection)

    @property
    def straight_bevel_sun_gear_system_deflection(
        self: "CastSelf",
    ) -> "_2905.StraightBevelSunGearSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2905,
        )

        return self.__parent__._cast(_2905.StraightBevelSunGearSystemDeflection)

    @property
    def synchroniser_half_system_deflection(
        self: "CastSelf",
    ) -> "_2906.SynchroniserHalfSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2906,
        )

        return self.__parent__._cast(_2906.SynchroniserHalfSystemDeflection)

    @property
    def synchroniser_part_system_deflection(
        self: "CastSelf",
    ) -> "_2907.SynchroniserPartSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2907,
        )

        return self.__parent__._cast(_2907.SynchroniserPartSystemDeflection)

    @property
    def synchroniser_sleeve_system_deflection(
        self: "CastSelf",
    ) -> "_2908.SynchroniserSleeveSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2908,
        )

        return self.__parent__._cast(_2908.SynchroniserSleeveSystemDeflection)

    @property
    def synchroniser_system_deflection(
        self: "CastSelf",
    ) -> "_2909.SynchroniserSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2909,
        )

        return self.__parent__._cast(_2909.SynchroniserSystemDeflection)

    @property
    def torque_converter_pump_system_deflection(
        self: "CastSelf",
    ) -> "_2914.TorqueConverterPumpSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2914,
        )

        return self.__parent__._cast(_2914.TorqueConverterPumpSystemDeflection)

    @property
    def torque_converter_system_deflection(
        self: "CastSelf",
    ) -> "_2915.TorqueConverterSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2915,
        )

        return self.__parent__._cast(_2915.TorqueConverterSystemDeflection)

    @property
    def torque_converter_turbine_system_deflection(
        self: "CastSelf",
    ) -> "_2916.TorqueConverterTurbineSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2916,
        )

        return self.__parent__._cast(_2916.TorqueConverterTurbineSystemDeflection)

    @property
    def unbalanced_mass_system_deflection(
        self: "CastSelf",
    ) -> "_2919.UnbalancedMassSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2919,
        )

        return self.__parent__._cast(_2919.UnbalancedMassSystemDeflection)

    @property
    def virtual_component_system_deflection(
        self: "CastSelf",
    ) -> "_2920.VirtualComponentSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2920,
        )

        return self.__parent__._cast(_2920.VirtualComponentSystemDeflection)

    @property
    def worm_gear_set_system_deflection(
        self: "CastSelf",
    ) -> "_2922.WormGearSetSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2922,
        )

        return self.__parent__._cast(_2922.WormGearSetSystemDeflection)

    @property
    def worm_gear_system_deflection(
        self: "CastSelf",
    ) -> "_2923.WormGearSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2923,
        )

        return self.__parent__._cast(_2923.WormGearSystemDeflection)

    @property
    def zerol_bevel_gear_set_system_deflection(
        self: "CastSelf",
    ) -> "_2925.ZerolBevelGearSetSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2925,
        )

        return self.__parent__._cast(_2925.ZerolBevelGearSetSystemDeflection)

    @property
    def zerol_bevel_gear_system_deflection(
        self: "CastSelf",
    ) -> "_2926.ZerolBevelGearSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2926,
        )

        return self.__parent__._cast(_2926.ZerolBevelGearSystemDeflection)

    @property
    def abstract_assembly_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6415.AbstractAssemblyDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6415,
        )

        return self.__parent__._cast(_6415.AbstractAssemblyDynamicAnalysis)

    @property
    def abstract_shaft_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6416.AbstractShaftDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6416,
        )

        return self.__parent__._cast(_6416.AbstractShaftDynamicAnalysis)

    @property
    def abstract_shaft_or_housing_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6417.AbstractShaftOrHousingDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6417,
        )

        return self.__parent__._cast(_6417.AbstractShaftOrHousingDynamicAnalysis)

    @property
    def agma_gleason_conical_gear_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6419.AGMAGleasonConicalGearDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6419,
        )

        return self.__parent__._cast(_6419.AGMAGleasonConicalGearDynamicAnalysis)

    @property
    def agma_gleason_conical_gear_set_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6421.AGMAGleasonConicalGearSetDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6421,
        )

        return self.__parent__._cast(_6421.AGMAGleasonConicalGearSetDynamicAnalysis)

    @property
    def assembly_dynamic_analysis(self: "CastSelf") -> "_6422.AssemblyDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6422,
        )

        return self.__parent__._cast(_6422.AssemblyDynamicAnalysis)

    @property
    def bearing_dynamic_analysis(self: "CastSelf") -> "_6423.BearingDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6423,
        )

        return self.__parent__._cast(_6423.BearingDynamicAnalysis)

    @property
    def belt_drive_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6425.BeltDriveDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6425,
        )

        return self.__parent__._cast(_6425.BeltDriveDynamicAnalysis)

    @property
    def bevel_differential_gear_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6426.BevelDifferentialGearDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6426,
        )

        return self.__parent__._cast(_6426.BevelDifferentialGearDynamicAnalysis)

    @property
    def bevel_differential_gear_set_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6428.BevelDifferentialGearSetDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6428,
        )

        return self.__parent__._cast(_6428.BevelDifferentialGearSetDynamicAnalysis)

    @property
    def bevel_differential_planet_gear_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6429.BevelDifferentialPlanetGearDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6429,
        )

        return self.__parent__._cast(_6429.BevelDifferentialPlanetGearDynamicAnalysis)

    @property
    def bevel_differential_sun_gear_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6430.BevelDifferentialSunGearDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6430,
        )

        return self.__parent__._cast(_6430.BevelDifferentialSunGearDynamicAnalysis)

    @property
    def bevel_gear_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6431.BevelGearDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6431,
        )

        return self.__parent__._cast(_6431.BevelGearDynamicAnalysis)

    @property
    def bevel_gear_set_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6433.BevelGearSetDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6433,
        )

        return self.__parent__._cast(_6433.BevelGearSetDynamicAnalysis)

    @property
    def bolt_dynamic_analysis(self: "CastSelf") -> "_6434.BoltDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6434,
        )

        return self.__parent__._cast(_6434.BoltDynamicAnalysis)

    @property
    def bolted_joint_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6435.BoltedJointDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6435,
        )

        return self.__parent__._cast(_6435.BoltedJointDynamicAnalysis)

    @property
    def clutch_dynamic_analysis(self: "CastSelf") -> "_6437.ClutchDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6437,
        )

        return self.__parent__._cast(_6437.ClutchDynamicAnalysis)

    @property
    def clutch_half_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6438.ClutchHalfDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6438,
        )

        return self.__parent__._cast(_6438.ClutchHalfDynamicAnalysis)

    @property
    def component_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6440.ComponentDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6440,
        )

        return self.__parent__._cast(_6440.ComponentDynamicAnalysis)

    @property
    def concept_coupling_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6442.ConceptCouplingDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6442,
        )

        return self.__parent__._cast(_6442.ConceptCouplingDynamicAnalysis)

    @property
    def concept_coupling_half_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6443.ConceptCouplingHalfDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6443,
        )

        return self.__parent__._cast(_6443.ConceptCouplingHalfDynamicAnalysis)

    @property
    def concept_gear_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6444.ConceptGearDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6444,
        )

        return self.__parent__._cast(_6444.ConceptGearDynamicAnalysis)

    @property
    def concept_gear_set_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6446.ConceptGearSetDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6446,
        )

        return self.__parent__._cast(_6446.ConceptGearSetDynamicAnalysis)

    @property
    def conical_gear_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6447.ConicalGearDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6447,
        )

        return self.__parent__._cast(_6447.ConicalGearDynamicAnalysis)

    @property
    def conical_gear_set_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6449.ConicalGearSetDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6449,
        )

        return self.__parent__._cast(_6449.ConicalGearSetDynamicAnalysis)

    @property
    def connector_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6451.ConnectorDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6451,
        )

        return self.__parent__._cast(_6451.ConnectorDynamicAnalysis)

    @property
    def coupling_dynamic_analysis(self: "CastSelf") -> "_6453.CouplingDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6453,
        )

        return self.__parent__._cast(_6453.CouplingDynamicAnalysis)

    @property
    def coupling_half_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6454.CouplingHalfDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6454,
        )

        return self.__parent__._cast(_6454.CouplingHalfDynamicAnalysis)

    @property
    def cvt_dynamic_analysis(self: "CastSelf") -> "_6456.CVTDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6456,
        )

        return self.__parent__._cast(_6456.CVTDynamicAnalysis)

    @property
    def cvt_pulley_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6457.CVTPulleyDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6457,
        )

        return self.__parent__._cast(_6457.CVTPulleyDynamicAnalysis)

    @property
    def cycloidal_assembly_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6458.CycloidalAssemblyDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6458,
        )

        return self.__parent__._cast(_6458.CycloidalAssemblyDynamicAnalysis)

    @property
    def cycloidal_disc_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6460.CycloidalDiscDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6460,
        )

        return self.__parent__._cast(_6460.CycloidalDiscDynamicAnalysis)

    @property
    def cylindrical_gear_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6462.CylindricalGearDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6462,
        )

        return self.__parent__._cast(_6462.CylindricalGearDynamicAnalysis)

    @property
    def cylindrical_gear_set_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6464.CylindricalGearSetDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6464,
        )

        return self.__parent__._cast(_6464.CylindricalGearSetDynamicAnalysis)

    @property
    def cylindrical_planet_gear_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6465.CylindricalPlanetGearDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6465,
        )

        return self.__parent__._cast(_6465.CylindricalPlanetGearDynamicAnalysis)

    @property
    def datum_dynamic_analysis(self: "CastSelf") -> "_6466.DatumDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6466,
        )

        return self.__parent__._cast(_6466.DatumDynamicAnalysis)

    @property
    def external_cad_model_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6469.ExternalCADModelDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6469,
        )

        return self.__parent__._cast(_6469.ExternalCADModelDynamicAnalysis)

    @property
    def face_gear_dynamic_analysis(self: "CastSelf") -> "_6470.FaceGearDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6470,
        )

        return self.__parent__._cast(_6470.FaceGearDynamicAnalysis)

    @property
    def face_gear_set_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6472.FaceGearSetDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6472,
        )

        return self.__parent__._cast(_6472.FaceGearSetDynamicAnalysis)

    @property
    def fe_part_dynamic_analysis(self: "CastSelf") -> "_6473.FEPartDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6473,
        )

        return self.__parent__._cast(_6473.FEPartDynamicAnalysis)

    @property
    def flexible_pin_assembly_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6474.FlexiblePinAssemblyDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6474,
        )

        return self.__parent__._cast(_6474.FlexiblePinAssemblyDynamicAnalysis)

    @property
    def gear_dynamic_analysis(self: "CastSelf") -> "_6475.GearDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6475,
        )

        return self.__parent__._cast(_6475.GearDynamicAnalysis)

    @property
    def gear_set_dynamic_analysis(self: "CastSelf") -> "_6477.GearSetDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6477,
        )

        return self.__parent__._cast(_6477.GearSetDynamicAnalysis)

    @property
    def guide_dxf_model_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6478.GuideDxfModelDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6478,
        )

        return self.__parent__._cast(_6478.GuideDxfModelDynamicAnalysis)

    @property
    def hypoid_gear_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6479.HypoidGearDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6479,
        )

        return self.__parent__._cast(_6479.HypoidGearDynamicAnalysis)

    @property
    def hypoid_gear_set_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6481.HypoidGearSetDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6481,
        )

        return self.__parent__._cast(_6481.HypoidGearSetDynamicAnalysis)

    @property
    def klingelnberg_cyclo_palloid_conical_gear_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6483.KlingelnbergCycloPalloidConicalGearDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6483,
        )

        return self.__parent__._cast(
            _6483.KlingelnbergCycloPalloidConicalGearDynamicAnalysis
        )

    @property
    def klingelnberg_cyclo_palloid_conical_gear_set_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6485.KlingelnbergCycloPalloidConicalGearSetDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6485,
        )

        return self.__parent__._cast(
            _6485.KlingelnbergCycloPalloidConicalGearSetDynamicAnalysis
        )

    @property
    def klingelnberg_cyclo_palloid_hypoid_gear_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6486.KlingelnbergCycloPalloidHypoidGearDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6486,
        )

        return self.__parent__._cast(
            _6486.KlingelnbergCycloPalloidHypoidGearDynamicAnalysis
        )

    @property
    def klingelnberg_cyclo_palloid_hypoid_gear_set_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6488.KlingelnbergCycloPalloidHypoidGearSetDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6488,
        )

        return self.__parent__._cast(
            _6488.KlingelnbergCycloPalloidHypoidGearSetDynamicAnalysis
        )

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_gear_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6489.KlingelnbergCycloPalloidSpiralBevelGearDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6489,
        )

        return self.__parent__._cast(
            _6489.KlingelnbergCycloPalloidSpiralBevelGearDynamicAnalysis
        )

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_gear_set_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6491.KlingelnbergCycloPalloidSpiralBevelGearSetDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6491,
        )

        return self.__parent__._cast(
            _6491.KlingelnbergCycloPalloidSpiralBevelGearSetDynamicAnalysis
        )

    @property
    def mass_disc_dynamic_analysis(self: "CastSelf") -> "_6492.MassDiscDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6492,
        )

        return self.__parent__._cast(_6492.MassDiscDynamicAnalysis)

    @property
    def measurement_component_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6493.MeasurementComponentDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6493,
        )

        return self.__parent__._cast(_6493.MeasurementComponentDynamicAnalysis)

    @property
    def microphone_array_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6494.MicrophoneArrayDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6494,
        )

        return self.__parent__._cast(_6494.MicrophoneArrayDynamicAnalysis)

    @property
    def microphone_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6495.MicrophoneDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6495,
        )

        return self.__parent__._cast(_6495.MicrophoneDynamicAnalysis)

    @property
    def mountable_component_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6496.MountableComponentDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6496,
        )

        return self.__parent__._cast(_6496.MountableComponentDynamicAnalysis)

    @property
    def oil_seal_dynamic_analysis(self: "CastSelf") -> "_6497.OilSealDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6497,
        )

        return self.__parent__._cast(_6497.OilSealDynamicAnalysis)

    @property
    def part_dynamic_analysis(self: "CastSelf") -> "_6498.PartDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6498,
        )

        return self.__parent__._cast(_6498.PartDynamicAnalysis)

    @property
    def part_to_part_shear_coupling_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6500.PartToPartShearCouplingDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6500,
        )

        return self.__parent__._cast(_6500.PartToPartShearCouplingDynamicAnalysis)

    @property
    def part_to_part_shear_coupling_half_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6501.PartToPartShearCouplingHalfDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6501,
        )

        return self.__parent__._cast(_6501.PartToPartShearCouplingHalfDynamicAnalysis)

    @property
    def planetary_gear_set_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6503.PlanetaryGearSetDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6503,
        )

        return self.__parent__._cast(_6503.PlanetaryGearSetDynamicAnalysis)

    @property
    def planet_carrier_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6504.PlanetCarrierDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6504,
        )

        return self.__parent__._cast(_6504.PlanetCarrierDynamicAnalysis)

    @property
    def point_load_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6505.PointLoadDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6505,
        )

        return self.__parent__._cast(_6505.PointLoadDynamicAnalysis)

    @property
    def power_load_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6506.PowerLoadDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6506,
        )

        return self.__parent__._cast(_6506.PowerLoadDynamicAnalysis)

    @property
    def pulley_dynamic_analysis(self: "CastSelf") -> "_6507.PulleyDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6507,
        )

        return self.__parent__._cast(_6507.PulleyDynamicAnalysis)

    @property
    def ring_pins_dynamic_analysis(self: "CastSelf") -> "_6508.RingPinsDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6508,
        )

        return self.__parent__._cast(_6508.RingPinsDynamicAnalysis)

    @property
    def rolling_ring_assembly_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6510.RollingRingAssemblyDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6510,
        )

        return self.__parent__._cast(_6510.RollingRingAssemblyDynamicAnalysis)

    @property
    def rolling_ring_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6512.RollingRingDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6512,
        )

        return self.__parent__._cast(_6512.RollingRingDynamicAnalysis)

    @property
    def root_assembly_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6513.RootAssemblyDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6513,
        )

        return self.__parent__._cast(_6513.RootAssemblyDynamicAnalysis)

    @property
    def shaft_dynamic_analysis(self: "CastSelf") -> "_6514.ShaftDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6514,
        )

        return self.__parent__._cast(_6514.ShaftDynamicAnalysis)

    @property
    def shaft_hub_connection_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6515.ShaftHubConnectionDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6515,
        )

        return self.__parent__._cast(_6515.ShaftHubConnectionDynamicAnalysis)

    @property
    def specialised_assembly_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6517.SpecialisedAssemblyDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6517,
        )

        return self.__parent__._cast(_6517.SpecialisedAssemblyDynamicAnalysis)

    @property
    def spiral_bevel_gear_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6518.SpiralBevelGearDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6518,
        )

        return self.__parent__._cast(_6518.SpiralBevelGearDynamicAnalysis)

    @property
    def spiral_bevel_gear_set_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6520.SpiralBevelGearSetDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6520,
        )

        return self.__parent__._cast(_6520.SpiralBevelGearSetDynamicAnalysis)

    @property
    def spring_damper_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6522.SpringDamperDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6522,
        )

        return self.__parent__._cast(_6522.SpringDamperDynamicAnalysis)

    @property
    def spring_damper_half_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6523.SpringDamperHalfDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6523,
        )

        return self.__parent__._cast(_6523.SpringDamperHalfDynamicAnalysis)

    @property
    def straight_bevel_diff_gear_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6524.StraightBevelDiffGearDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6524,
        )

        return self.__parent__._cast(_6524.StraightBevelDiffGearDynamicAnalysis)

    @property
    def straight_bevel_diff_gear_set_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6526.StraightBevelDiffGearSetDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6526,
        )

        return self.__parent__._cast(_6526.StraightBevelDiffGearSetDynamicAnalysis)

    @property
    def straight_bevel_gear_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6527.StraightBevelGearDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6527,
        )

        return self.__parent__._cast(_6527.StraightBevelGearDynamicAnalysis)

    @property
    def straight_bevel_gear_set_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6529.StraightBevelGearSetDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6529,
        )

        return self.__parent__._cast(_6529.StraightBevelGearSetDynamicAnalysis)

    @property
    def straight_bevel_planet_gear_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6530.StraightBevelPlanetGearDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6530,
        )

        return self.__parent__._cast(_6530.StraightBevelPlanetGearDynamicAnalysis)

    @property
    def straight_bevel_sun_gear_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6531.StraightBevelSunGearDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6531,
        )

        return self.__parent__._cast(_6531.StraightBevelSunGearDynamicAnalysis)

    @property
    def synchroniser_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6532.SynchroniserDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6532,
        )

        return self.__parent__._cast(_6532.SynchroniserDynamicAnalysis)

    @property
    def synchroniser_half_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6533.SynchroniserHalfDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6533,
        )

        return self.__parent__._cast(_6533.SynchroniserHalfDynamicAnalysis)

    @property
    def synchroniser_part_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6534.SynchroniserPartDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6534,
        )

        return self.__parent__._cast(_6534.SynchroniserPartDynamicAnalysis)

    @property
    def synchroniser_sleeve_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6535.SynchroniserSleeveDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6535,
        )

        return self.__parent__._cast(_6535.SynchroniserSleeveDynamicAnalysis)

    @property
    def torque_converter_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6537.TorqueConverterDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6537,
        )

        return self.__parent__._cast(_6537.TorqueConverterDynamicAnalysis)

    @property
    def torque_converter_pump_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6538.TorqueConverterPumpDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6538,
        )

        return self.__parent__._cast(_6538.TorqueConverterPumpDynamicAnalysis)

    @property
    def torque_converter_turbine_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6539.TorqueConverterTurbineDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6539,
        )

        return self.__parent__._cast(_6539.TorqueConverterTurbineDynamicAnalysis)

    @property
    def unbalanced_mass_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6540.UnbalancedMassDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6540,
        )

        return self.__parent__._cast(_6540.UnbalancedMassDynamicAnalysis)

    @property
    def virtual_component_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6541.VirtualComponentDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6541,
        )

        return self.__parent__._cast(_6541.VirtualComponentDynamicAnalysis)

    @property
    def worm_gear_dynamic_analysis(self: "CastSelf") -> "_6542.WormGearDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6542,
        )

        return self.__parent__._cast(_6542.WormGearDynamicAnalysis)

    @property
    def worm_gear_set_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6544.WormGearSetDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6544,
        )

        return self.__parent__._cast(_6544.WormGearSetDynamicAnalysis)

    @property
    def zerol_bevel_gear_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6545.ZerolBevelGearDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6545,
        )

        return self.__parent__._cast(_6545.ZerolBevelGearDynamicAnalysis)

    @property
    def zerol_bevel_gear_set_dynamic_analysis(
        self: "CastSelf",
    ) -> "_6547.ZerolBevelGearSetDynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6547,
        )

        return self.__parent__._cast(_6547.ZerolBevelGearSetDynamicAnalysis)

    @property
    def part_fe_analysis(self: "CastSelf") -> "PartFEAnalysis":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class PartFEAnalysis(_7713.PartStaticLoadAnalysisCase):
    """PartFEAnalysis

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _PART_FE_ANALYSIS

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_PartFEAnalysis":
        """Cast to another type.

        Returns:
            _Cast_PartFEAnalysis
        """
        return _Cast_PartFEAnalysis(self)



"""DataInputFileOptions"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.type_enforcement import enforce_parameter_types
from mastapy._private._internal.sentinels import ListWithSelectedItem_None
from mastapy._private._internal import constructor, conversion, utility
from mastapy._private._internal.implicit import overridable, list_with_selected_item
from mastapy._private._internal.overridable_constructor import _unpack_overridable
from mastapy._private import _0
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_DATA_INPUT_FILE_OPTIONS = python_net_import(
    "SMT.MastaAPI.UtilityGUI", "DataInputFileOptions"
)

if TYPE_CHECKING:
    from typing import Any, Type, Union, Tuple, List, TypeVar

    from mastapy._private.system_model.part_model.gears.supercharger_rotor_set import (
        _2614,
    )
    from mastapy._private.system_model.analyses_and_results.static_loads.duty_cycle_definition import (
        _7145,
    )

    Self = TypeVar("Self", bound="DataInputFileOptions")
    CastSelf = TypeVar(
        "CastSelf", bound="DataInputFileOptions._Cast_DataInputFileOptions"
    )


__docformat__ = "restructuredtext en"
__all__ = ("DataInputFileOptions",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_DataInputFileOptions:
    """Special nested class for casting DataInputFileOptions to subclasses."""

    __parent__: "DataInputFileOptions"

    @property
    def rotor_set_data_input_file_options(
        self: "CastSelf",
    ) -> "_2614.RotorSetDataInputFileOptions":
        from mastapy._private.system_model.part_model.gears.supercharger_rotor_set import (
            _2614,
        )

        return self.__parent__._cast(_2614.RotorSetDataInputFileOptions)

    @property
    def multi_time_series_data_input_file_options(
        self: "CastSelf",
    ) -> "_7145.MultiTimeSeriesDataInputFileOptions":
        from mastapy._private.system_model.analyses_and_results.static_loads.duty_cycle_definition import (
            _7145,
        )

        return self.__parent__._cast(_7145.MultiTimeSeriesDataInputFileOptions)

    @property
    def data_input_file_options(self: "CastSelf") -> "DataInputFileOptions":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class DataInputFileOptions(_0.APIBase):
    """DataInputFileOptions

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _DATA_INPUT_FILE_OPTIONS

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def column_headers_row(self: "Self") -> "int":
        """int"""
        temp = self.wrapped.ColumnHeadersRow

        if temp is None:
            return 0

        return temp

    @column_headers_row.setter
    @enforce_parameter_types
    def column_headers_row(self: "Self", value: "int") -> None:
        self.wrapped.ColumnHeadersRow = int(value) if value is not None else 0

    @property
    def data_end_row(self: "Self") -> "overridable.Overridable_int":
        """Overridable[int]"""
        temp = self.wrapped.DataEndRow

        if temp is None:
            return 0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_int"
        )(temp)

    @data_end_row.setter
    @enforce_parameter_types
    def data_end_row(self: "Self", value: "Union[int, Tuple[int, bool]]") -> None:
        wrapper_type = overridable.Overridable_int.wrapper_type()
        enclosed_type = overridable.Overridable_int.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0, is_overridden
        )
        self.wrapped.DataEndRow = value

    @property
    def data_start_row(self: "Self") -> "overridable.Overridable_int":
        """Overridable[int]"""
        temp = self.wrapped.DataStartRow

        if temp is None:
            return 0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_int"
        )(temp)

    @data_start_row.setter
    @enforce_parameter_types
    def data_start_row(self: "Self", value: "Union[int, Tuple[int, bool]]") -> None:
        wrapper_type = overridable.Overridable_int.wrapper_type()
        enclosed_type = overridable.Overridable_int.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0, is_overridden
        )
        self.wrapped.DataStartRow = value

    @property
    def selected_file_name(self: "Self") -> "str":
        """str"""
        temp = self.wrapped.SelectedFileName

        if temp is None:
            return ""

        return temp

    @selected_file_name.setter
    @enforce_parameter_types
    def selected_file_name(self: "Self", value: "str") -> None:
        self.wrapped.SelectedFileName = str(value) if value is not None else ""

    @property
    def sheet(self: "Self") -> "list_with_selected_item.ListWithSelectedItem_str":
        """ListWithSelectedItem[str]"""
        temp = self.wrapped.Sheet

        if temp is None:
            return ""

        selected_value = temp.SelectedValue

        if selected_value is None:
            return ListWithSelectedItem_None(temp)

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.list_with_selected_item",
            "ListWithSelectedItem_str",
        )(temp)

    @sheet.setter
    @enforce_parameter_types
    def sheet(self: "Self", value: "str") -> None:
        wrapper_type = list_with_selected_item.ListWithSelectedItem_str.wrapper_type()
        enclosed_type = list_with_selected_item.ListWithSelectedItem_str.implicit_type()
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else ""
        )
        self.wrapped.Sheet = value

    @property
    def report_names(self: "Self") -> "List[str]":
        """List[str]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ReportNames

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp, str)

        if value is None:
            return None

        return value

    @enforce_parameter_types
    def open_file(self: "Self", filename: "str") -> None:
        """Method does not return.

        Args:
            filename (str)
        """
        filename = str(filename)
        self.wrapped.OpenFile(filename if filename else "")

    @enforce_parameter_types
    def output_default_report_to(self: "Self", file_path: "str") -> None:
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        self.wrapped.OutputDefaultReportTo(file_path if file_path else "")

    def get_default_report_with_encoded_images(self: "Self") -> "str":
        """str"""
        method_result = self.wrapped.GetDefaultReportWithEncodedImages()
        return method_result

    @enforce_parameter_types
    def output_active_report_to(self: "Self", file_path: "str") -> None:
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        self.wrapped.OutputActiveReportTo(file_path if file_path else "")

    @enforce_parameter_types
    def output_active_report_as_text_to(self: "Self", file_path: "str") -> None:
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        self.wrapped.OutputActiveReportAsTextTo(file_path if file_path else "")

    def get_active_report_with_encoded_images(self: "Self") -> "str":
        """str"""
        method_result = self.wrapped.GetActiveReportWithEncodedImages()
        return method_result

    @enforce_parameter_types
    def output_named_report_to(
        self: "Self", report_name: "str", file_path: "str"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportTo(
            report_name if report_name else "", file_path if file_path else ""
        )

    @enforce_parameter_types
    def output_named_report_as_masta_report(
        self: "Self", report_name: "str", file_path: "str"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsMastaReport(
            report_name if report_name else "", file_path if file_path else ""
        )

    @enforce_parameter_types
    def output_named_report_as_text_to(
        self: "Self", report_name: "str", file_path: "str"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsTextTo(
            report_name if report_name else "", file_path if file_path else ""
        )

    @enforce_parameter_types
    def get_named_report_with_encoded_images(self: "Self", report_name: "str") -> "str":
        """str

        Args:
            report_name (str)
        """
        report_name = str(report_name)
        method_result = self.wrapped.GetNamedReportWithEncodedImages(
            report_name if report_name else ""
        )
        return method_result

    @property
    def cast_to(self: "Self") -> "_Cast_DataInputFileOptions":
        """Cast to another type.

        Returns:
            _Cast_DataInputFileOptions
        """
        return _Cast_DataInputFileOptions(self)



"""Subpackage."""

from typing import TYPE_CHECKING as __tc


if __tc:
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7422 import (
        AbstractAssemblyAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7423 import (
        AbstractShaftAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7424 import (
        AbstractShaftOrHousingAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7425 import (
        AbstractShaftToMountableComponentConnectionAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7426 import (
        AdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7427 import (
        AdvancedSystemDeflectionOptions,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7428 import (
        AdvancedSystemDeflectionSubAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7429 import (
        AGMAGleasonConicalGearAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7430 import (
        AGMAGleasonConicalGearMeshAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7431 import (
        AGMAGleasonConicalGearSetAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7432 import (
        AssemblyAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7433 import (
        BearingAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7434 import (
        BeltConnectionAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7435 import (
        BeltDriveAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7436 import (
        BevelDifferentialGearAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7437 import (
        BevelDifferentialGearMeshAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7438 import (
        BevelDifferentialGearSetAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7439 import (
        BevelDifferentialPlanetGearAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7440 import (
        BevelDifferentialSunGearAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7441 import (
        BevelGearAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7442 import (
        BevelGearMeshAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7443 import (
        BevelGearSetAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7444 import (
        BoltAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7445 import (
        BoltedJointAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7446 import (
        ClutchAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7447 import (
        ClutchConnectionAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7448 import (
        ClutchHalfAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7449 import (
        CoaxialConnectionAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7450 import (
        ComponentAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7451 import (
        ConceptCouplingAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7452 import (
        ConceptCouplingConnectionAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7453 import (
        ConceptCouplingHalfAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7454 import (
        ConceptGearAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7455 import (
        ConceptGearMeshAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7456 import (
        ConceptGearSetAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7457 import (
        ConicalGearAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7458 import (
        ConicalGearMeshAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7459 import (
        ConicalGearSetAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7460 import (
        ConnectionAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7461 import (
        ConnectorAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7462 import (
        ContactChartPerToothPass,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7463 import (
        CouplingAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7464 import (
        CouplingConnectionAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7465 import (
        CouplingHalfAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7466 import (
        CVTAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7467 import (
        CVTBeltConnectionAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7468 import (
        CVTPulleyAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7469 import (
        CycloidalAssemblyAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7470 import (
        CycloidalDiscAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7471 import (
        CycloidalDiscCentralBearingConnectionAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7472 import (
        CycloidalDiscPlanetaryBearingConnectionAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7473 import (
        CylindricalGearAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7474 import (
        CylindricalGearMeshAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7475 import (
        CylindricalGearSetAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7476 import (
        CylindricalMeshedGearAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7477 import (
        CylindricalPlanetGearAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7478 import (
        DatumAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7479 import (
        ExternalCADModelAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7480 import (
        FaceGearAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7481 import (
        FaceGearMeshAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7482 import (
        FaceGearSetAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7483 import (
        FEPartAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7484 import (
        FlexiblePinAssemblyAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7485 import (
        GearAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7486 import (
        GearMeshAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7487 import (
        GearSetAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7488 import (
        GuideDxfModelAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7489 import (
        HypoidGearAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7490 import (
        HypoidGearMeshAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7491 import (
        HypoidGearSetAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7492 import (
        InterMountableComponentConnectionAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7493 import (
        KlingelnbergCycloPalloidConicalGearAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7494 import (
        KlingelnbergCycloPalloidConicalGearMeshAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7495 import (
        KlingelnbergCycloPalloidConicalGearSetAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7496 import (
        KlingelnbergCycloPalloidHypoidGearAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7497 import (
        KlingelnbergCycloPalloidHypoidGearMeshAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7498 import (
        KlingelnbergCycloPalloidHypoidGearSetAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7499 import (
        KlingelnbergCycloPalloidSpiralBevelGearAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7500 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7501 import (
        KlingelnbergCycloPalloidSpiralBevelGearSetAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7502 import (
        UseLtcaInAsdOption,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7503 import (
        MassDiscAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7504 import (
        MeasurementComponentAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7505 import (
        MicrophoneAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7506 import (
        MicrophoneArrayAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7507 import (
        MountableComponentAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7508 import (
        OilSealAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7509 import (
        PartAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7510 import (
        PartToPartShearCouplingAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7511 import (
        PartToPartShearCouplingConnectionAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7512 import (
        PartToPartShearCouplingHalfAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7513 import (
        PlanetaryConnectionAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7514 import (
        PlanetaryGearSetAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7515 import (
        PlanetCarrierAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7516 import (
        PointLoadAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7517 import (
        PowerLoadAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7518 import (
        PulleyAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7519 import (
        RingPinsAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7520 import (
        RingPinsToDiscConnectionAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7521 import (
        RollingRingAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7522 import (
        RollingRingAssemblyAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7523 import (
        RollingRingConnectionAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7524 import (
        RootAssemblyAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7525 import (
        ShaftAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7526 import (
        ShaftHubConnectionAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7527 import (
        ShaftToMountableComponentConnectionAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7528 import (
        SpecialisedAssemblyAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7529 import (
        SpiralBevelGearAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7530 import (
        SpiralBevelGearMeshAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7531 import (
        SpiralBevelGearSetAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7532 import (
        SpringDamperAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7533 import (
        SpringDamperConnectionAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7534 import (
        SpringDamperHalfAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7535 import (
        StraightBevelDiffGearAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7536 import (
        StraightBevelDiffGearMeshAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7537 import (
        StraightBevelDiffGearSetAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7538 import (
        StraightBevelGearAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7539 import (
        StraightBevelGearMeshAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7540 import (
        StraightBevelGearSetAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7541 import (
        StraightBevelPlanetGearAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7542 import (
        StraightBevelSunGearAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7543 import (
        SynchroniserAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7544 import (
        SynchroniserHalfAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7545 import (
        SynchroniserPartAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7546 import (
        SynchroniserSleeveAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7547 import (
        TorqueConverterAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7548 import (
        TorqueConverterConnectionAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7549 import (
        TorqueConverterPumpAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7550 import (
        TorqueConverterTurbineAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7551 import (
        TransmissionErrorToOtherPowerLoad,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7552 import (
        UnbalancedMassAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7553 import (
        VirtualComponentAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7554 import (
        WormGearAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7555 import (
        WormGearMeshAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7556 import (
        WormGearSetAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7557 import (
        ZerolBevelGearAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7558 import (
        ZerolBevelGearMeshAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7559 import (
        ZerolBevelGearSetAdvancedSystemDeflection,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.analyses_and_results.advanced_system_deflections._7422": [
            "AbstractAssemblyAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7423": [
            "AbstractShaftAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7424": [
            "AbstractShaftOrHousingAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7425": [
            "AbstractShaftToMountableComponentConnectionAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7426": [
            "AdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7427": [
            "AdvancedSystemDeflectionOptions"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7428": [
            "AdvancedSystemDeflectionSubAnalysis"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7429": [
            "AGMAGleasonConicalGearAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7430": [
            "AGMAGleasonConicalGearMeshAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7431": [
            "AGMAGleasonConicalGearSetAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7432": [
            "AssemblyAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7433": [
            "BearingAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7434": [
            "BeltConnectionAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7435": [
            "BeltDriveAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7436": [
            "BevelDifferentialGearAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7437": [
            "BevelDifferentialGearMeshAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7438": [
            "BevelDifferentialGearSetAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7439": [
            "BevelDifferentialPlanetGearAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7440": [
            "BevelDifferentialSunGearAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7441": [
            "BevelGearAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7442": [
            "BevelGearMeshAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7443": [
            "BevelGearSetAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7444": [
            "BoltAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7445": [
            "BoltedJointAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7446": [
            "ClutchAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7447": [
            "ClutchConnectionAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7448": [
            "ClutchHalfAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7449": [
            "CoaxialConnectionAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7450": [
            "ComponentAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7451": [
            "ConceptCouplingAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7452": [
            "ConceptCouplingConnectionAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7453": [
            "ConceptCouplingHalfAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7454": [
            "ConceptGearAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7455": [
            "ConceptGearMeshAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7456": [
            "ConceptGearSetAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7457": [
            "ConicalGearAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7458": [
            "ConicalGearMeshAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7459": [
            "ConicalGearSetAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7460": [
            "ConnectionAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7461": [
            "ConnectorAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7462": [
            "ContactChartPerToothPass"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7463": [
            "CouplingAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7464": [
            "CouplingConnectionAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7465": [
            "CouplingHalfAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7466": [
            "CVTAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7467": [
            "CVTBeltConnectionAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7468": [
            "CVTPulleyAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7469": [
            "CycloidalAssemblyAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7470": [
            "CycloidalDiscAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7471": [
            "CycloidalDiscCentralBearingConnectionAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7472": [
            "CycloidalDiscPlanetaryBearingConnectionAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7473": [
            "CylindricalGearAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7474": [
            "CylindricalGearMeshAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7475": [
            "CylindricalGearSetAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7476": [
            "CylindricalMeshedGearAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7477": [
            "CylindricalPlanetGearAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7478": [
            "DatumAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7479": [
            "ExternalCADModelAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7480": [
            "FaceGearAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7481": [
            "FaceGearMeshAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7482": [
            "FaceGearSetAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7483": [
            "FEPartAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7484": [
            "FlexiblePinAssemblyAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7485": [
            "GearAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7486": [
            "GearMeshAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7487": [
            "GearSetAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7488": [
            "GuideDxfModelAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7489": [
            "HypoidGearAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7490": [
            "HypoidGearMeshAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7491": [
            "HypoidGearSetAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7492": [
            "InterMountableComponentConnectionAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7493": [
            "KlingelnbergCycloPalloidConicalGearAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7494": [
            "KlingelnbergCycloPalloidConicalGearMeshAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7495": [
            "KlingelnbergCycloPalloidConicalGearSetAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7496": [
            "KlingelnbergCycloPalloidHypoidGearAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7497": [
            "KlingelnbergCycloPalloidHypoidGearMeshAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7498": [
            "KlingelnbergCycloPalloidHypoidGearSetAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7499": [
            "KlingelnbergCycloPalloidSpiralBevelGearAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7500": [
            "KlingelnbergCycloPalloidSpiralBevelGearMeshAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7501": [
            "KlingelnbergCycloPalloidSpiralBevelGearSetAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7502": [
            "UseLtcaInAsdOption"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7503": [
            "MassDiscAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7504": [
            "MeasurementComponentAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7505": [
            "MicrophoneAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7506": [
            "MicrophoneArrayAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7507": [
            "MountableComponentAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7508": [
            "OilSealAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7509": [
            "PartAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7510": [
            "PartToPartShearCouplingAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7511": [
            "PartToPartShearCouplingConnectionAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7512": [
            "PartToPartShearCouplingHalfAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7513": [
            "PlanetaryConnectionAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7514": [
            "PlanetaryGearSetAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7515": [
            "PlanetCarrierAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7516": [
            "PointLoadAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7517": [
            "PowerLoadAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7518": [
            "PulleyAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7519": [
            "RingPinsAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7520": [
            "RingPinsToDiscConnectionAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7521": [
            "RollingRingAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7522": [
            "RollingRingAssemblyAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7523": [
            "RollingRingConnectionAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7524": [
            "RootAssemblyAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7525": [
            "ShaftAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7526": [
            "ShaftHubConnectionAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7527": [
            "ShaftToMountableComponentConnectionAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7528": [
            "SpecialisedAssemblyAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7529": [
            "SpiralBevelGearAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7530": [
            "SpiralBevelGearMeshAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7531": [
            "SpiralBevelGearSetAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7532": [
            "SpringDamperAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7533": [
            "SpringDamperConnectionAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7534": [
            "SpringDamperHalfAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7535": [
            "StraightBevelDiffGearAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7536": [
            "StraightBevelDiffGearMeshAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7537": [
            "StraightBevelDiffGearSetAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7538": [
            "StraightBevelGearAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7539": [
            "StraightBevelGearMeshAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7540": [
            "StraightBevelGearSetAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7541": [
            "StraightBevelPlanetGearAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7542": [
            "StraightBevelSunGearAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7543": [
            "SynchroniserAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7544": [
            "SynchroniserHalfAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7545": [
            "SynchroniserPartAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7546": [
            "SynchroniserSleeveAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7547": [
            "TorqueConverterAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7548": [
            "TorqueConverterConnectionAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7549": [
            "TorqueConverterPumpAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7550": [
            "TorqueConverterTurbineAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7551": [
            "TransmissionErrorToOtherPowerLoad"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7552": [
            "UnbalancedMassAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7553": [
            "VirtualComponentAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7554": [
            "WormGearAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7555": [
            "WormGearMeshAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7556": [
            "WormGearSetAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7557": [
            "ZerolBevelGearAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7558": [
            "ZerolBevelGearMeshAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7559": [
            "ZerolBevelGearSetAdvancedSystemDeflection"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AbstractAssemblyAdvancedSystemDeflection",
    "AbstractShaftAdvancedSystemDeflection",
    "AbstractShaftOrHousingAdvancedSystemDeflection",
    "AbstractShaftToMountableComponentConnectionAdvancedSystemDeflection",
    "AdvancedSystemDeflection",
    "AdvancedSystemDeflectionOptions",
    "AdvancedSystemDeflectionSubAnalysis",
    "AGMAGleasonConicalGearAdvancedSystemDeflection",
    "AGMAGleasonConicalGearMeshAdvancedSystemDeflection",
    "AGMAGleasonConicalGearSetAdvancedSystemDeflection",
    "AssemblyAdvancedSystemDeflection",
    "BearingAdvancedSystemDeflection",
    "BeltConnectionAdvancedSystemDeflection",
    "BeltDriveAdvancedSystemDeflection",
    "BevelDifferentialGearAdvancedSystemDeflection",
    "BevelDifferentialGearMeshAdvancedSystemDeflection",
    "BevelDifferentialGearSetAdvancedSystemDeflection",
    "BevelDifferentialPlanetGearAdvancedSystemDeflection",
    "BevelDifferentialSunGearAdvancedSystemDeflection",
    "BevelGearAdvancedSystemDeflection",
    "BevelGearMeshAdvancedSystemDeflection",
    "BevelGearSetAdvancedSystemDeflection",
    "BoltAdvancedSystemDeflection",
    "BoltedJointAdvancedSystemDeflection",
    "ClutchAdvancedSystemDeflection",
    "ClutchConnectionAdvancedSystemDeflection",
    "ClutchHalfAdvancedSystemDeflection",
    "CoaxialConnectionAdvancedSystemDeflection",
    "ComponentAdvancedSystemDeflection",
    "ConceptCouplingAdvancedSystemDeflection",
    "ConceptCouplingConnectionAdvancedSystemDeflection",
    "ConceptCouplingHalfAdvancedSystemDeflection",
    "ConceptGearAdvancedSystemDeflection",
    "ConceptGearMeshAdvancedSystemDeflection",
    "ConceptGearSetAdvancedSystemDeflection",
    "ConicalGearAdvancedSystemDeflection",
    "ConicalGearMeshAdvancedSystemDeflection",
    "ConicalGearSetAdvancedSystemDeflection",
    "ConnectionAdvancedSystemDeflection",
    "ConnectorAdvancedSystemDeflection",
    "ContactChartPerToothPass",
    "CouplingAdvancedSystemDeflection",
    "CouplingConnectionAdvancedSystemDeflection",
    "CouplingHalfAdvancedSystemDeflection",
    "CVTAdvancedSystemDeflection",
    "CVTBeltConnectionAdvancedSystemDeflection",
    "CVTPulleyAdvancedSystemDeflection",
    "CycloidalAssemblyAdvancedSystemDeflection",
    "CycloidalDiscAdvancedSystemDeflection",
    "CycloidalDiscCentralBearingConnectionAdvancedSystemDeflection",
    "CycloidalDiscPlanetaryBearingConnectionAdvancedSystemDeflection",
    "CylindricalGearAdvancedSystemDeflection",
    "CylindricalGearMeshAdvancedSystemDeflection",
    "CylindricalGearSetAdvancedSystemDeflection",
    "CylindricalMeshedGearAdvancedSystemDeflection",
    "CylindricalPlanetGearAdvancedSystemDeflection",
    "DatumAdvancedSystemDeflection",
    "ExternalCADModelAdvancedSystemDeflection",
    "FaceGearAdvancedSystemDeflection",
    "FaceGearMeshAdvancedSystemDeflection",
    "FaceGearSetAdvancedSystemDeflection",
    "FEPartAdvancedSystemDeflection",
    "FlexiblePinAssemblyAdvancedSystemDeflection",
    "GearAdvancedSystemDeflection",
    "GearMeshAdvancedSystemDeflection",
    "GearSetAdvancedSystemDeflection",
    "GuideDxfModelAdvancedSystemDeflection",
    "HypoidGearAdvancedSystemDeflection",
    "HypoidGearMeshAdvancedSystemDeflection",
    "HypoidGearSetAdvancedSystemDeflection",
    "InterMountableComponentConnectionAdvancedSystemDeflection",
    "KlingelnbergCycloPalloidConicalGearAdvancedSystemDeflection",
    "KlingelnbergCycloPalloidConicalGearMeshAdvancedSystemDeflection",
    "KlingelnbergCycloPalloidConicalGearSetAdvancedSystemDeflection",
    "KlingelnbergCycloPalloidHypoidGearAdvancedSystemDeflection",
    "KlingelnbergCycloPalloidHypoidGearMeshAdvancedSystemDeflection",
    "KlingelnbergCycloPalloidHypoidGearSetAdvancedSystemDeflection",
    "KlingelnbergCycloPalloidSpiralBevelGearAdvancedSystemDeflection",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshAdvancedSystemDeflection",
    "KlingelnbergCycloPalloidSpiralBevelGearSetAdvancedSystemDeflection",
    "UseLtcaInAsdOption",
    "MassDiscAdvancedSystemDeflection",
    "MeasurementComponentAdvancedSystemDeflection",
    "MicrophoneAdvancedSystemDeflection",
    "MicrophoneArrayAdvancedSystemDeflection",
    "MountableComponentAdvancedSystemDeflection",
    "OilSealAdvancedSystemDeflection",
    "PartAdvancedSystemDeflection",
    "PartToPartShearCouplingAdvancedSystemDeflection",
    "PartToPartShearCouplingConnectionAdvancedSystemDeflection",
    "PartToPartShearCouplingHalfAdvancedSystemDeflection",
    "PlanetaryConnectionAdvancedSystemDeflection",
    "PlanetaryGearSetAdvancedSystemDeflection",
    "PlanetCarrierAdvancedSystemDeflection",
    "PointLoadAdvancedSystemDeflection",
    "PowerLoadAdvancedSystemDeflection",
    "PulleyAdvancedSystemDeflection",
    "RingPinsAdvancedSystemDeflection",
    "RingPinsToDiscConnectionAdvancedSystemDeflection",
    "RollingRingAdvancedSystemDeflection",
    "RollingRingAssemblyAdvancedSystemDeflection",
    "RollingRingConnectionAdvancedSystemDeflection",
    "RootAssemblyAdvancedSystemDeflection",
    "ShaftAdvancedSystemDeflection",
    "ShaftHubConnectionAdvancedSystemDeflection",
    "ShaftToMountableComponentConnectionAdvancedSystemDeflection",
    "SpecialisedAssemblyAdvancedSystemDeflection",
    "SpiralBevelGearAdvancedSystemDeflection",
    "SpiralBevelGearMeshAdvancedSystemDeflection",
    "SpiralBevelGearSetAdvancedSystemDeflection",
    "SpringDamperAdvancedSystemDeflection",
    "SpringDamperConnectionAdvancedSystemDeflection",
    "SpringDamperHalfAdvancedSystemDeflection",
    "StraightBevelDiffGearAdvancedSystemDeflection",
    "StraightBevelDiffGearMeshAdvancedSystemDeflection",
    "StraightBevelDiffGearSetAdvancedSystemDeflection",
    "StraightBevelGearAdvancedSystemDeflection",
    "StraightBevelGearMeshAdvancedSystemDeflection",
    "StraightBevelGearSetAdvancedSystemDeflection",
    "StraightBevelPlanetGearAdvancedSystemDeflection",
    "StraightBevelSunGearAdvancedSystemDeflection",
    "SynchroniserAdvancedSystemDeflection",
    "SynchroniserHalfAdvancedSystemDeflection",
    "SynchroniserPartAdvancedSystemDeflection",
    "SynchroniserSleeveAdvancedSystemDeflection",
    "TorqueConverterAdvancedSystemDeflection",
    "TorqueConverterConnectionAdvancedSystemDeflection",
    "TorqueConverterPumpAdvancedSystemDeflection",
    "TorqueConverterTurbineAdvancedSystemDeflection",
    "TransmissionErrorToOtherPowerLoad",
    "UnbalancedMassAdvancedSystemDeflection",
    "VirtualComponentAdvancedSystemDeflection",
    "WormGearAdvancedSystemDeflection",
    "WormGearMeshAdvancedSystemDeflection",
    "WormGearSetAdvancedSystemDeflection",
    "ZerolBevelGearAdvancedSystemDeflection",
    "ZerolBevelGearMeshAdvancedSystemDeflection",
    "ZerolBevelGearSetAdvancedSystemDeflection",
)
